@@ -13,9 +13,13 @@ setMethodS3("colMeans", "default", function(...) {
   base::colMeans(...);
 })
 
+# Make sure to use the same generic function as in 'matrixStats'
+colMedians <- matrixStats::colMedians;
+
 #colnames <- function(...) UseMethod("colnames", ...);
 #colnames.default <- function(...) base::colnames(...);
 
+write <- appendVarArgs(write);
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -27,6 +31,11 @@ setGenericS3("process", overwrite=TRUE);
 
 ############################################################################
 # HISTORY:
+# 2013-08-03 [HB]
+# o Now aroma.core use the same type of generic colMedians() function
+#   as matrixStats.
+# 2012-07-20 [HB]
+# o Added '...' to write(), because we no longer attach R.rsp.
 # 2012-03-01 [HB]
 # o Replaced all appendVarArgs() for 'base' functions that do .Internal()
 #   calls, because they would then appear as local functions of this
