@@ -13,7 +13,6 @@
 #   \item{model}{A @see "CopyNumberChromosomalModel" object.}
 #   \item{zooms}{An positive @integer @vector specifying for which zoom
 #    levels the graphics should be generated.}
-#   \item{version}{The version of the Explorer HTML/Javascript generated/used.}
 #   \item{...}{Not used.}
 # }
 #
@@ -39,7 +38,7 @@
 #  @see "CopyNumberChromosomalModel".
 # }
 #*/###########################################################################
-setConstructorS3("ChromosomeExplorer", function(model=NULL, zooms=2^(0:6), version=c("3.4", "3"), ...) {
+setConstructorS3("ChromosomeExplorer", function(model=NULL, zooms=2^(0:6), ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -54,12 +53,9 @@ setConstructorS3("ChromosomeExplorer", function(model=NULL, zooms=2^(0:6), versi
   } else {
     zooms <- Arguments$getDoubles(zooms, range=c(0, Inf));
   }
+
   
-  # Argument 'version':
-  version <- match.arg(version);
-
-
-  extend(Explorer(version=version, ...), c("ChromosomeExplorer"),
+  extend(Explorer(...), c("ChromosomeExplorer"),
     .model = model,
     .arrays = NULL,
     .plotCytoband = TRUE,
@@ -73,7 +69,6 @@ setMethodS3("as.character", "ChromosomeExplorer", function(x, ...) {
   this <- x;
 
   s <- sprintf("%s:", class(this)[1]);
-  s <- c(s, sprintf("Version: %s", getVersion(this)));
   s <- c(s, sprintf("Name: %s", getName(this)));
   s <- c(s, sprintf("Tags: %s", paste(getTags(this), collapse=",")));
   s <- c(s, sprintf("Number of arrays: %d", nbrOfArrays(this)));
@@ -81,7 +76,7 @@ setMethodS3("as.character", "ChromosomeExplorer", function(x, ...) {
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
   class(s) <- "GenericSummary";
   s;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 setMethodS3("setCytoband", "ChromosomeExplorer", function(this, status=TRUE, ...) {
@@ -205,14 +200,8 @@ setMethodS3("getPath", "ChromosomeExplorer", function(this, ...) {
   set <- getSetTag(model);
 
   # The full path
-  path <- filePath(mainPath, chipType, set, expandLinks="any");
-
-  # Create path?
-  if (!isDirectory(path)) {
-    mkdirs(path);
-    if (!isDirectory(path))
-      throw("Failed to create output directory: ", path);
-  }
+  path <- filePath(mainPath, chipType, set);
+  path <- Arguments$getWritablePath(path);
 
   path;
 })
@@ -269,7 +258,7 @@ setMethodS3("getChromosomeLabels", "ChromosomeExplorer", function(this, ...) {
   }
 
   chrsL;
-})
+}, protected=TRUE)
 
 
 setMethodS3("getZooms", "ChromosomeExplorer", function(this, ...) {
@@ -297,7 +286,7 @@ setMethodS3("setZooms", "ChromosomeExplorer", function(this, zooms=NULL, ...) {
 setMethodS3("getSampleLabels", "ChromosomeExplorer", function(this, ...) {
   labels <- getNames(this, ...);
   labels;
-})
+}, protected=TRUE)
 
 
 setMethodS3("writeGraphs", "ChromosomeExplorer", function(x, arrays=NULL, ...) {
@@ -378,20 +367,8 @@ setMethodS3("writeRegions", "ChromosomeExplorer", function(this, arrays=NULL, nb
 
 
 
-setMethodS3("addIndexFile", "ChromosomeExplorer", function(this, filename=NULL, ...) {
-  if (is.null(filename)) {
-    version <- getVersion(this);
-    if (version == "3") {
-      filename <- "ChromosomeExplorer.html";
-    } else if (version == "3.4") {
-      filename <- "ChromosomeExplorer.html";
-    } else if (version == "4") {
-      filename <- "ChromosomeExplorer4.html";
-    } else if (version == "5") {
-      filename <- "ChromosomeExplorer5.html";
-    }
-  }
-  NextMethod("addIndexFile", this, filename=filename, ...);
+setMethodS3("addIndexFile", "ChromosomeExplorer", function(this, filename="ChromosomeExplorer.html", ...) {
+  NextMethod("addIndexFile", filename=filename);
 }, protected=TRUE)
 
 
@@ -435,27 +412,16 @@ setMethodS3("updateSetupExplorerFile", "ChromosomeExplorer", function(this, ...,
     on.exit(popState(verbose));
   }
 
-
-  # Output version
-  version <- getVersion(this);
-  verbose && cat(verbose, "Explorer output version: ", version);
-
-
   path <- getPath(this);
   parentPath <- getParent(path);
   parent2Path <- getParent(parentPath);
   parent3Path <- getParent(parent2Path);
 
   srcPath <- getTemplatePath(this);
-  if (version == "3") {
-    pathname <- filePath(srcPath, "rsp", "ChromosomeExplorer3", "ChromosomeExplorer.onLoad.js.rsp");
-  } else if (version == "3.4") {
-    pathname <- filePath(srcPath, "rsp", "ChromosomeExplorer3.4", "setupExplorer.js.rsp");
-  } else if (version == "4") {
-    pathname <- filePath(srcPath, "rsp", "ChromosomeExplorer4", "ChromosomeExplorer4.onLoad.js.rsp");
-  } else if (version == "5") {
-    pathname <- filePath(srcPath, "rsp", "ChromosomeExplorer5", "ChromosomeExplorer5.onLoad.js.rsp");
-  }
+  pathT <- file.path(srcPath, "rsp", "ChromosomeExplorer");
+  filenameT <- "setupExplorer.js.rsp";
+  pathname <- filePath(pathT, filenameT);
+
   verbose && enter(verbose, "Compiling ", basename(pathname));
   verbose && cat(verbose, "Source: ", pathname);
   outFile <- gsub("[.]rsp$", "", basename(pathname));
@@ -682,13 +648,15 @@ setMethodS3("process", "ChromosomeExplorer", function(this, arrays=NULL, chromos
 
 
 setMethodS3("display", "ChromosomeExplorer", function(this, filename="ChromosomeExplorer.html", ...) {
-  NextMethod("display", this, filename=filename, ...);
+  NextMethod("display", filename=filename);
 })
 
 
 
 ##############################################################################
 # HISTORY:
+# 2012-10-18
+# o CLEANUP: Drop all usage of 'version' in ChromosomeExplorer.
 # 2012-03-06
 # o Dropped setup() for ChromosomeExplorer, because now Explorer has one.
 # o Renamed updateSamplesFile() to updateSetupExplorerFile().
