@@ -31,19 +31,17 @@ setMethodS3("as.CopyNumberDataSet", "CopyNumberDataSet", function(this, ...) {
 })
 
 setMethodS3("hasAlleleBFractions", "CopyNumberDataSet", function(this, ...) {
-  if (length(this) == 0) {
+  if (length(this) == 0L) {
     throw("Cannot infer hasAlleleBFractions(). No data files: ", getFullName(this));
   }
-  df <- getFile(this, 1);
-  hasAlleleBFractions(df);
+  hasAlleleBFractions(getOneFile(this));
 })
 
 setMethodS3("hasStrandiness", "CopyNumberDataSet", function(this, ...) {
-  if (length(this) == 0) {
+  if (length(this) == 0L) {
     throw("Cannot infer hasStrandiness(). No data files: ", getFullName(this));
   }
-  df <- getFile(this, 1);
-  hasStrandiness(df);
+  hasStrandiness(getOneFile(this));
 })
 
 
